@@ -40,34 +40,13 @@ aov.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE)
   df1=length(x.levels)-1
   df2=n-length(x.levels)
   
-  
   Ftest=ssb/df1*df2/ssw
   
-  
-  
   p.value=pf(Ftest,df1,df2,lower.tail = F)
-  
-  
-  
-  
+    
   if (verbose) {
-    cat("\n", "",METHOD,paste("(alpha = ",alpha,")",sep = ""), "\n", 
-        sep = " ")
-    cat("-------------------------------------------------------------", 
-        "\n", sep = " ")
-    cat("  data :", DNAME, "\n\n", sep = " ")
-    cat("  statistic  :", Ftest, "\n", sep = " ")
-    cat("  num df     :", df1, "\n", sep = " ")
-    cat("  denom df   :", df2, "\n", sep = " ")
-    cat("  p.value    :", p.value, "\n\n", sep = " ")
-    cat(if (p.value > alpha) {
-      "  Result     : Difference is not statistically significant."
-    }
-    else {
-      "  Result     : Difference is statistically significant."
-    }, "\n")
-    cat("-------------------------------------------------------------", 
-        "\n\n", sep = " ")
+  print(structure(list(statistic = c("F" = Ftest), parameter = c("num df" = df1, "denom df" = df2), 
+                 p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
   }
   
   result <- list()
