@@ -76,31 +76,11 @@ gp.test<-function(formula, data, method = c("gtb","gtf"), alpha = 0.05, na.rm =
     METHOD <- "Generalized Test Equivalent to Parametric Bootstrap Test (size close to intended)"
     p.value <- g2pval
   }
-  
-  
+    
   if (verbose) {
-    cat("\n", "",METHOD, paste("(alpha = ",alpha,")",sep = ""), "\n", 
-        sep = " ")
-    line<-paste(rep("-",nchar(METHOD)+19),sep = "")
-    cat(line, 
-        "\n", sep = "")
-    cat("  data :", DNAME, "\n\n", sep = " ")
-    
-    
-    cat("  p.value    :", p.value, "\n\n", sep = " ")
-    cat(if (p.value > alpha) {
-      "  Result     : Difference is not statistically significant."
-    }
-    else {
-      "  Result     : Difference is statistically significant."
-    }, "\n")
-    cat(line, 
-        "\n\n", sep = "")
+  print(structure(list(p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
   }
   
-  
-  
-  
   result <- list()
   result$p.value <- p.value
   result$alpha <- alpha
