@@ -38,27 +38,11 @@ kw.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE){
   p.value<-pchisq(approx, df=(length(x.levels)-1),lower.tail = FALSE)
   df=(length(x.levels)-1)
   
-  
   if (verbose) {
-    cat("\n", "",METHOD, paste("(alpha = ",alpha,")",sep = ""),"\n", 
-        sep = " ")
-    cat("-------------------------------------------------------------", 
-        "\n", sep = " ")
-    cat("  data :", DNAME, "\n\n", sep = " ")
-    cat("  statistic  :", approx, "\n", sep = " ")
-    cat("  parameter  :", df, "\n", sep = " ")
-    cat("  p.value    :", p.value, "\n\n", sep = " ")
-    cat(if (p.value > alpha) {
-      "  Result     : Difference is not statistically significant."
-    }
-    else {
-      "  Result     : Difference is statistically significant."
-    }, "\n")
-    cat("-------------------------------------------------------------", 
-        "\n\n", sep = " ")
+  print(structure(list(statistic = c("X-squared" = approx), parameter = c("df" = df), 
+                 p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
   }
   
-  
   result <- list()
   result$statistic <- approx
   result$parameter <- df
