@@ -26,9 +26,7 @@ mw.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
   
   n <- length(y)
   x.levels <- levels(factor(group))
-  
-  DNAME <- paste(x.levels[1], "vs.", x.levels[2])
-  
+    
   y.n <- tapply(y, group, length)
   
   
@@ -66,29 +64,10 @@ mw.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
   
   p.value <- 2*pnorm(abs(Ztest),lower.tail = F)
   
-  
-  
-  
   if (verbose) {
-    cat("\n", "",METHOD, paste("(alpha = ",alpha,")",sep = ""), "\n", 
-        sep = " ")
-    cat("-------------------------------------------------------------", 
-        "\n", sep = " ")
-    cat("  Groups :", DNAME, "\n\n", sep = " ")
-    cat("  statistic  :", Ztest, "\n", sep = " ")
-    cat("  p.value    :", p.value, "\n\n", sep = " ")
-    cat(if (p.value > alpha) {
-      "  Result     : Difference is not statistically significant."
-    }
-    else {
-      "  Result     : Difference is statistically significant."
-    }, "\n")
-    cat("-------------------------------------------------------------", 
-        "\n\n", sep = " ")
+  print(structure(list(statistic = setNames(Ztest, "z"), p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
   }
   
-  
-  
   result <- list()
   result$statistic <- Ztest
   result$p.value <- p.value
