@@ -27,8 +27,7 @@ st.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
   n <- length(y)
   x.levels <- levels(factor(group))
   
-  DNAME <- paste(x.levels[1], "vs.", x.levels[2])
-  
+    
   
   y.means <- tapply(y, group, mean)
   
@@ -42,30 +41,11 @@ st.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
   
   p.value <- 2*pt(abs(Ttest),df,lower.tail = F)
   
-  
-  
-  
   if (verbose) {
-    cat("\n", "",METHOD, paste("(alpha = ",alpha,")",sep = ""), "\n", 
-        sep = " ")
-    cat("-------------------------------------------------------------", 
-        "\n", sep = " ")
-    cat("  Groups :", DNAME, "\n\n", sep = " ")
-    cat("  statistic  :", Ttest, "\n", sep = " ")
-    cat("  parameter  :", df, "\n", sep = " ")
-    cat("  p.value    :", p.value, "\n\n", sep = " ")
-    cat(if (p.value > alpha) {
-      "  Result     : Difference is not statistically significant."
-    }
-    else {
-      "  Result     : Difference is statistically significant."
-    }, "\n")
-    cat("-------------------------------------------------------------", 
-        "\n\n", sep = " ")
+  print(structure(list(statistic = setNames(Ttest, "t"), parameter = setNames(df, "df"), 
+                 p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
   }
   
-  
-  
   result <- list()
   result$statistic <- Ttest
   result$parameter <- df
