@@ -75,26 +75,9 @@ welch.test <- function(formula, data, rate = 0, alpha = 0.05, na.rm = TRUE, verb
   
   p.value=pf(Ftest,df1,df2,lower.tail = F)
   
-  
-  
   if (verbose) {
-    cat("\n", "",METHOD, paste("(alpha = ",alpha,")",sep = ""), "\n", 
-        sep = " ")
-    cat(if (rate!=0){"----------------------------------------------------------------------------------------------"}else{"-------------------------------------------------------------"}, 
-        "\n", sep = " ")
-    cat("  data :", DNAME, "\n\n", sep = " ")
-    cat("  statistic  :", Ftest, "\n", sep = " ")
-    cat("  num df     :", df1, "\n", sep = " ")
-    cat("  denom df   :", df2, "\n", sep = " ")
-    cat("  p.value    :", p.value, "\n\n", sep = " ")
-    cat(if (p.value > alpha) {
-      "  Result     : Difference is not statistically significant."
-    }
-    else {
-      "  Result     : Difference is statistically significant."
-    }, "\n")
-    cat(if (rate!=0){"----------------------------------------------------------------------------------------------"}else{"-------------------------------------------------------------"}, 
-        "\n", sep = " ")
+  print(structure(list(statistic = c("F" = Ftest), parameter = c("num df" = df1, "denom df" = df2), 
+                 p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
   }
   
   result <- list()
